Module: RubyEmoji
- Defined in:
- lib/ruby_emoji.rb,
lib/ruby_emoji/parser.rb,
lib/ruby_emoji/version.rb
Defined Under Namespace
Classes: Parser
Constant Summary collapse
- EMOJI_LIST =
{ ":smile:"=>"๐", ":laughing:"=>"๐", ":blush:"=>"๐", ":smiley:"=>"๐", ":relaxed:"=>"โบ๏ธ", ":smirk:"=>"๐", ":heart_eyes:"=>"๐", ":kissing_heart:"=>"๐", ":kissing_closed_eyes:"=>"๐", ":flushed:"=>"๐ณ", ":relieved:"=>"๐", ":satisfied:"=>"๐", ":grin:"=>"๐", ":wink:"=>"๐", ":stuck_out_tongue_winking_eye:"=>"๐", ":stuck_out_tongue_closed_eyes:"=>"๐", ":grinning:"=>"๐", ":kissing:"=>"๐", ":kissing_smiling_eyes:"=>"๐", ":stuck_out_tongue:"=>"๐", ":sleeping:"=>"๐ด", ":worried:"=>"๐", ":frowning:"=>"๐ฆ", ":anguished:"=>"๐ง", ":open_mouth:"=>"๐ฎ", ":grimacing:"=>"๐ฌ", ":confused:"=>"๐", ":hushed:"=>"๐ฏ", ":expressionless:"=>"๐", ":unamused:"=>"๐", ":sweat_smile:"=>"๐ ", ":sweat:"=>"๐", ":disappointed_relieved:"=>"๐ฅ", ":weary:"=>"๐ฉ", ":pensive:"=>"๐", ":disappointed:"=>"๐", ":confounded:"=>"๐", ":fearful:"=>"๐จ", ":cold_sweat:"=>"๐ฐ", ":persevere:"=>"๐ฃ", ":cry:"=>"๐ข", ":sob:"=>"๐ญ", ":joy:"=>"๐", ":astonished:"=>"๐ฒ", ":scream:"=>"๐ฑ", ":tired_face:"=>"๐ซ", ":angry:"=>"๐ ", ":rage:"=>"๐ก", ":triumph:"=>"๐ค", ":sleepy:"=>"๐ช", ":yum:"=>"๐", ":mask:"=>"๐ท", ":sunglasses:"=>"๐", ":dizzy_face:"=>"๐ต", ":imp:"=>"๐ฟ", ":smiling_imp:"=>"๐", ":neutral_face:"=>"๐", ":no_mouth:"=>"๐ถ", ":innocent:"=>"๐", ":alien:"=>"๐ฝ", ":yellow_heart:"=>"๐", ":blue_heart:"=>"๐", ":purple_heart:"=>"๐", ":heart:"=>"โค", ":green_heart:"=>"๐", ":broken_heart:"=>"๐", ":heartbeat:"=>"๐", ":heartpulse:"=>"๐", ":two_hearts:"=>"๐", ":revolving_hearts:"=>"๐", ":cupid:"=>"๐", ":sparkling_heart:"=>"๐", ":sparkles:"=>"โจ", ":star:"=>"โญ๏ธ", ":star2:"=>"๐", ":dizzy:"=>"๐ซ", ":boom:"=>"๐ฅ", ":collision:"=>"๐ฅ", ":anger:"=>"๐ข", ":exclamation:"=>"โ", ":question:"=>"โ", ":grey_exclamation:"=>"โ", ":grey_question:"=>"โ", ":zzz:"=>"๐ค", ":dash:"=>"๐จ", ":sweat_drops:"=>"๐ฆ", ":notes:"=>"๐ถ", ":musical_note:"=>"๐ต", ":fire:"=>"๐ฅ", ":hankey:"=>"๐ฉ", ":poop:"=>"๐ฉ", ":shit:"=>"๐ฉ", ":+1:"=>"๐", ":thumbsup:"=>"๐", ":-1:"=>"๐", ":thumbsdown:"=>"๐", ":ok_hand:"=>"๐", ":punch:"=>"๐", ":facepunch:"=>"๐", ":fist:"=>"โ", ":v:"=>"โ", ":wave:"=>"๐", ":hand:"=>"โ", ":raised_hand:"=>"โ", ":open_hands:"=>"๐", ":point_up:"=>"โ", ":point_down:"=>"๐", ":point_left:"=>"๐", ":point_right:"=>"๐", ":raised_hands:"=>"๐", ":pray:"=>"๐", ":point_up_2:"=>"๐", ":clap:"=>"๐", ":muscle:"=>"๐ช", ":metal:"=>"๐ค", ":fu:"=>"๐", ":runner:"=>"๐", ":running:"=>"๐", ":couple:"=>"๐ซ", ":family:"=>"๐ช", ":two_men_holding_hands:"=>"๐ฌ", ":two_women_holding_hands:"=>"๐ญ", ":dancer:"=>"๐", ":dancers:"=>"๐ฏ", ":ok_woman:"=>"๐", ":no_good:"=>"๐ ", ":information_desk_person:"=>"๐", ":raising_hand:"=>"๐", ":bride_with_veil:"=>"๐ฐ", ":person_with_pouting_face:"=>"๐", ":person_frowning:"=>"๐", ":bow:"=>"๐", ":couplekiss:"=>"๐", ":couple_with_heart:"=>"๐", ":massage:"=>"๐", ":haircut:"=>"๐", ":nail_care:"=>"๐ ", ":boy:"=>"๐ฆ", ":girl:"=>"๐ง", ":woman:"=>"๐ฉ", ":man:"=>"๐จ", ":baby:"=>"๐ถ", ":older_woman:"=>"๐ต", ":older_man:"=>"๐ด", ":person_with_blond_hair:"=>"๐ฑ", ":man_with_gua_pi_mao:"=>"๐ฒ", ":man_with_turban:"=>"๐ณ", ":construction_worker:"=>"๐ท", ":cop:"=>"๐ฎ", ":angel:"=>"๐ผ", ":princess:"=>"๐ธ", ":smiley_cat:"=>"๐บ", ":smile_cat:"=>"๐ธ", ":heart_eyes_cat:"=>"๐ป", ":kissing_cat:"=>"๐ฝ", ":smirk_cat:"=>"๐ผ", ":scream_cat:"=>"๐", ":crying_cat_face:"=>"๐ฟ", ":joy_cat:"=>"๐น", ":pouting_cat:"=>"๐พ", ":japanese_ogre:"=>"๐น", ":japanese_goblin:"=>"๐บ", ":see_no_evil:"=>"๐", ":hear_no_evil:"=>"๐", ":speak_no_evil:"=>"๐", ":guardsman:"=>"๐", ":skull:"=>"๐", ":feet:"=>"๐พ", ":lips:"=>"๐", ":kiss:"=>"๐", ":droplet:"=>"๐ง", ":ear:"=>"๐", ":eyes:"=>"๐", ":nose:"=>"๐", ":tongue:"=>"๐ ", ":love_letter:"=>"๐", ":bust_in_silhouette:"=>"๐ค", ":busts_in_silhouette:"=>"๐ฅ", ":speech_balloon:"=>"๐ฌ", ":thought_balloon:"=>"๐ญ", ":sunny:"=>"โ๏ธ", ":umbrella:"=>"โ๏ธ", ":cloud:"=>"โ", ":snowflake:"=>"โ", ":snowman:"=>"โ๏ธ", ":zap:"=>"โก๏ธ", ":cyclone:"=>"๐", ":foggy:"=>"๐", ":ocean:"=>"๐", ":cat:"=>"๐ฑ", ":dog:"=>"๐ถ", ":mouse:"=>"๐ญ", ":hamster:"=>"๐น", ":rabbit:"=>"๐ฐ", ":wolf:"=>"๐บ", ":frog:"=>"๐ธ", ":tiger:"=>"๐ฏ", ":koala:"=>"๐จ", ":bear:"=>"๐ป", ":pig:"=>"๐ท", ":pig_nose:"=>"๐ฝ", ":cow:"=>"๐ฎ", ":boar:"=>"๐", ":monkey_face:"=>"๐ต", ":monkey:"=>"๐", ":horse:"=>"๐ด", ":racehorse:"=>"๐", ":camel:"=>"๐ซ", ":sheep:"=>"๐", ":elephant:"=>"๐", ":panda_face:"=>"๐ผ", ":snake:"=>"๐", ":bird:"=>"๐ฆ", ":baby_chick:"=>"๐ค", ":hatched_chick:"=>"๐ฅ", ":hatching_chick:"=>"๐ฃ", ":chicken:"=>"๐", ":penguin:"=>"๐ง", ":turtle:"=>"๐ข", ":bug:"=>"๐", ":honeybee:"=>"๐", ":ant:"=>"๐", ":beetle:"=>"๐", ":snail:"=>"๐", ":octopus:"=>"๐", ":tropical_fish:"=>"๐ ", ":fish:"=>"๐", ":whale:"=>"๐ณ", ":whale2:"=>"๐", ":dolphin:"=>"๐ฌ", ":cow2:"=>"๐", ":ram:"=>"๐", ":rat:"=>"๐", ":water_buffalo:"=>"๐", ":tiger2:"=>"๐ ", ":rabbit2:"=>"๐", ":dragon:"=>"๐", ":goat:"=>"๐", ":rooster:"=>"๐", ":dog2:"=>"๐", ":pig2:"=>"๐", ":mouse2:"=>"๐", ":ox:"=>"๐", ":dragon_face:"=>"๐ฒ", ":blowfish:"=>"๐ก", ":crocodile:"=>"๐", ":dromedary_camel:"=>"๐ช", ":leopard:"=>"๐", ":cat2:"=>"๐", ":poodle:"=>"๐ฉ", ":paw_prints:"=>"๐พ", ":bouquet:"=>"๐", ":cherry_blossom:"=>"๐ธ", ":tulip:"=>"๐ท", ":four_leaf_clover:"=>"๐", ":rose:"=>"๐น", ":sunflower:"=>"๐ป", ":hibiscus:"=>"๐บ", ":maple_leaf:"=>"๐", ":leaves:"=>"๐", ":fallen_leaf:"=>"๐", ":herb:"=>"๐ฟ", ":mushroom:"=>"๐", ":cactus:"=>"๐ต", ":palm_tree:"=>"๐ด", ":evergreen_tree:"=>"๐ฒ", ":deciduous_tree:"=>"๐ณ", ":chestnut:"=>"๐ฐ", ":seedling:"=>"๐ฑ", ":blossom:"=>"๐ผ", ":ear_of_rice:"=>"๐พ", ":shell:"=>"๐", ":globe_with_meridians:"=>"๐", ":sun_with_face:"=>"๐", ":full_moon_with_face:"=>"๐", ":new_moon_with_face:"=>"๐", ":new_moon:"=>"๐", ":waxing_crescent_moon:"=>"๐", ":first_quarter_moon:"=>"๐", ":waxing_gibbous_moon:"=>"๐", ":full_moon:"=>"๐", ":waning_gibbous_moon:"=>"๐", ":last_quarter_moon:"=>"๐", ":waning_crescent_moon:"=>"๐", ":last_quarter_moon_with_face:"=>"๐", ":first_quarter_moon_with_face:"=>"๐", ":crescent_moon:"=>"๐", ":earth_africa:"=>"๐", ":earth_americas:"=>"๐", ":earth_asia:"=>"๐", ":volcano:"=>"๐", ":milky_way:"=>"๐", ":partly_sunny:"=>"โ ๏ธ", ":bamboo:"=>"๐", ":gift_heart:"=>"๐", ":dolls:"=>"๐", ":school_satchel:"=>"๐", ":mortar_board:"=>"๐", ":flags:"=>"๐", ":fireworks:"=>"๐", ":sparkler:"=>"๐", ":wind_chime:"=>"๐", ":rice_scene:"=>"๐", ":jack_o_lantern:"=>"๐", ":ghost:"=>"๐ป", ":santa:"=>"๐ ", ":christmas_tree:"=>"๐", ":gift:"=>"๐", ":bell:"=>"๐", ":no_bell:"=>"๐", ":tanabata_tree:"=>"๐", ":tada:"=>"๐", ":confetti_ball:"=>"๐", ":balloon:"=>"๐", ":crystal_ball:"=>"๐ฎ", ":cd:"=>"๐ฟ", ":dvd:"=>"๐", ":floppy_disk:"=>"๐พ", ":camera:"=>"๐ท", ":video_camera:"=>"๐น", ":movie_camera:"=>"๐ฅ", ":computer:"=>"๐ป", ":tv:"=>"๐บ", ":iphone:"=>"๐ฑ", ":phone:"=>"โ๏ธ", ":telephone:"=>"โ๏ธ", ":telephone_receiver:"=>"๐", ":pager:"=>"๐", ":fax:"=>"๐ ", ":minidisc:"=>"๐ฝ", ":vhs:"=>"๐ผ", ":sound:"=>"๐", ":speaker:"=>"๐", ":mute:"=>"๐", ":loudspeaker:"=>"๐", ":mega:"=>"๐ฃ", ":hourglass:"=>"โ", ":hourglass_flowing_sand:"=>"โณ", ":alarm_clock:"=>"โฐ", ":watch:"=>"โ", ":radio:"=>"๐ป", ":satellite:"=>"๐ฐ", ":loop:"=>"โฟ", ":mag:"=>"๐", ":mag_right:"=>"๐", ":unlock:"=>"๐", ":lock:"=>"๐", ":lock_with_ink_pen:"=>"๐", ":closed_lock_with_key:"=>"๐", ":key:"=>"๐", ":bulb:"=>"๐ก", ":flashlight:"=>"๐ฆ", ":high_brightness:"=>"๐", ":low_brightness:"=>"๐ ", ":electric_plug:"=>"๐", ":battery:"=>"๐", ":calling:"=>"๐ฒ", ":email:"=>"โ๏ธ", ":mailbox:"=>"๐ซ", ":postbox:"=>"๐ฎ", ":bath:"=>"๐", ":bathtub:"=>"๐", ":shower:"=>"๐ฟ", ":toilet:"=>"๐ฝ", ":wrench:"=>"๐ง", ":nut_and_bolt:"=>"๐ฉ", ":hammer:"=>"๐จ", ":seat:"=>"๐บ", ":moneybag:"=>"๐ฐ", ":yen:"=>"๐ด", ":dollar:"=>"๐ต", ":pound:"=>"๐ท", ":euro:"=>"๐ถ", ":credit_card:"=>"๐ณ", ":money_with_wings:"=>"๐ธ", ":e-mail:"=>"๐ง", ":inbox_tray:"=>"๐ฅ", ":outbox_tray:"=>"๐ค", ":envelope:"=>"โ", ":incoming_envelope:"=>"๐จ", ":postal_horn:"=>"๐ฏ", ":mailbox_closed:"=>"๐ช", ":mailbox_with_mail:"=>"๐ฌ", ":mailbox_with_no_mail:"=>"๐ญ", ":package:"=>"๐ฆ", ":door:"=>"๐ช", ":smoking:"=>"๐ฌ", ":bomb:"=>"๐ฃ", ":gun:"=>"๐ซ", ":hocho:"=>"๐ช", ":pill:"=>"๐", ":syringe:"=>"๐", ":page_facing_up:"=>"๐", ":page_with_curl:"=>"๐", ":bookmark_tabs:"=>"๐", ":bar_chart:"=>"๐", ":chart_with_upwards_trend:"=>"๐", ":chart_with_downwards_trend:"=>"๐", ":scroll:"=>"๐", ":clipboard:"=>"๐", ":calendar:"=>"๐ ", ":date:"=>"๐ ", ":card_index:"=>"๐", ":file_folder:"=>"๐", ":open_file_folder:"=>"๐", ":scissors:"=>"โ", ":pushpin:"=>"๐", ":paperclip:"=>"๐", ":black_nib:"=>"โ", ":pencil2:"=>"โ", ":straight_ruler:"=>"๐", ":triangular_ruler:"=>"๐", ":closed_book:"=>"๐", ":green_book:"=>"๐", ":blue_book:"=>"๐", ":orange_book:"=>"๐", ":notebook:"=>"๐", ":notebook_with_decorative_cover:"=>"๐", ":ledger:"=>"๐", ":books:"=>"๐", ":bookmark:"=>"๐", ":name_badge:"=>"๐", ":microscope:"=>"๐ฌ", ":telescope:"=>"๐ญ", ":newspaper:"=>"๐ฐ", ":football:"=>"๐", ":basketball:"=>"๐", ":soccer:"=>"โฝ๏ธ", ":baseball:"=>"โพ", ":tennis:"=>"๐พ", ":8ball:"=>"๐ฑ", ":rugby_football:"=>"๐", ":bowling:"=>"๐ณ", ":golf:"=>"โณ๏ธ", ":mountain_bicyclist:"=>"๐ต", ":bicyclist:"=>"๐ด", ":horse_racing:"=>"๐", ":snowboarder:"=>"๐", ":swimmer:"=>"๐", ":surfer:"=>"๐", ":ski:"=>"๐ฟ", ":spades:"=>"โ ๏ธ", ":hearts:"=>"โค๏ธ", ":clubs:"=>"โฃ๏ธ", ":diamonds:"=>"โฆ๏ธ", ":gem:"=>"๐", ":ring:"=>"๐", ":trophy:"=>"๐", ":musical_score:"=>"๐ผ", ":musical_keyboard:"=>"๐น", ":violin:"=>"๐ป", ":space_invader:"=>"๐พ", ":video_game:"=>"๐ฎ", ":black_joker:"=>"๐", ":flower_playing_cards:"=>"๐ด", ":game_die:"=>"๐ฒ", ":dart:"=>"๐ฏ", ":mahjong:"=>"๐๏ธ", ":clapper:"=>"๐ฌ", ":memo:"=>"๐", ":pencil:"=>"โ", ":book:"=>"๐", ":art:"=>"๐จ", ":microphone:"=>"๐ค", ":headphones:"=>"๐ง", ":trumpet:"=>"๐บ", ":saxophone:"=>"๐ท", ":guitar:"=>"๐ธ", ":shoe:"=>"๐", ":sandal:"=>"๐ก", ":high_heel:"=>"๐ ", ":lipstick:"=>"๐", ":boot:"=>"๐ข", ":shirt:"=>"๐", ":tshirt:"=>"๐", ":necktie:"=>"๐", ":womans_clothes:"=>"๐", ":dress:"=>"๐", ":running_shirt_with_sash:"=>"๐ฝ", ":jeans:"=>"๐", ":kimono:"=>"๐", ":bikini:"=>"๐", ":ribbon:"=>"๐", ":tophat:"=>"๐ฉ", ":crown:"=>"๐", ":womans_hat:"=>"๐", ":mans_shoe:"=>"๐", ":closed_umbrella:"=>"๐", ":briefcase:"=>"๐ผ", ":handbag:"=>"๐", ":pouch:"=>"๐", ":purse:"=>"๐", ":eyeglasses:"=>"๐", ":fishing_pole_and_fish:"=>"๐ฃ", ":coffee:"=>"โ๏ธ", ":tea:"=>"๐ต", ":sake:"=>"๐ถ", ":baby_bottle:"=>"๐ผ", ":beer:"=>"๐บ", ":beers:"=>"๐ป", ":cocktail:"=>"๐ธ", ":tropical_drink:"=>"๐น", ":wine_glass:"=>"๐ท", ":fork_and_knife:"=>"๐ด", ":pizza:"=>"๐", ":hamburger:"=>"๐", ":fries:"=>"๐", ":poultry_leg:"=>"๐", ":meat_on_bone:"=>"๐", ":spaghetti:"=>"๐", ":curry:"=>"๐", ":fried_shrimp:"=>"๐ค", ":bento:"=>"๐ฑ", ":sushi:"=>"๐ฃ", ":fish_cake:"=>"๐ฅ", ":rice_ball:"=>"๐", ":rice_cracker:"=>"๐", ":rice:"=>"๐", ":ramen:"=>"๐", ":stew:"=>"๐ฒ", ":oden:"=>"๐ข", ":dango:"=>"๐ก", ":egg:"=>"๐ณ", ":bread:"=>"๐", ":doughnut:"=>"๐ฉ", ":custard:"=>"๐ฎ", ":icecream:"=>"๐ฆ", ":ice_cream:"=>"๐จ", ":shaved_ice:"=>"๐ง", ":birthday:"=>"๐", ":cake:"=>"๐ฐ", ":cookie:"=>"๐ช", ":chocolate_bar:"=>"๐ซ", ":candy:"=>"๐ฌ", ":lollipop:"=>"๐ญ", ":honey_pot:"=>"๐ฏ", ":apple:"=>"๐", ":green_apple:"=>"๐", ":tangerine:"=>"๐", ":lemon:"=>"๐", ":cherries:"=>"๐", ":grapes:"=>"๐", ":watermelon:"=>"๐", ":strawberry:"=>"๐", ":peach:"=>"๐", ":melon:"=>"๐", ":banana:"=>"๐", ":pear:"=>"๐", ":pineapple:"=>"๐", ":sweet_potato:"=>"๐ ", ":eggplant:"=>"๐", ":tomato:"=>"๐ ", ":corn:"=>"๐ฝ", ":house:"=>"๐ ", ":house_with_garden:"=>"๐ก", ":school:"=>"๐ซ", ":office:"=>"๐ข", ":post_office:"=>"๐ฃ", ":hospital:"=>"๐ฅ", ":bank:"=>"๐ฆ", ":convenience_store:"=>"๐ช", ":love_hotel:"=>"๐ฉ", ":hotel:"=>"๐จ", ":wedding:"=>"๐", ":church:"=>"โช", ":department_store:"=>"๐ฌ", ":european_post_office:"=>"๐ค", ":city_sunrise:"=>"๐", ":city_sunset:"=>"๐", ":japanese_castle:"=>"๐ฏ", ":european_castle:"=>"๐ฐ", ":tent:"=>"โบ", ":factory:"=>"๐ญ", ":tokyo_tower:"=>"๐ผ", ":japan:"=>"๐พ", ":mount_fuji:"=>"๐ป", ":sunrise_over_mountains:"=>"๐", ":sunrise:"=>"๐ ", ":stars:"=>"๐", ":statue_of_liberty:"=>"๐ฝ", ":bridge_at_night:"=>"๐", ":carousel_horse:"=>"๐ ", ":rainbow:"=>"๐", ":ferris_wheel:"=>"๐ก", ":fountain:"=>"โฒ", ":roller_coaster:"=>"๐ข", ":ship:"=>"๐ข", ":speedboat:"=>"๐ค", ":boat:"=>"โต", ":sailboat:"=>"โต", ":rowboat:"=>"๐ฃ", ":anchor:"=>"โ", ":rocket:"=>"๐", ":airplane:"=>"โ", ":helicopter:"=>"๐", ":steam_locomotive:"=>"๐", ":tram:"=>"๐", ":mountain_railway:"=>"๐", ":bike:"=>"๐ฒ", ":aerial_tramway:"=>"๐ก", ":suspension_railway:"=>"๐", ":mountain_cableway:"=>"๐ ", ":tractor:"=>"๐", ":blue_car:"=>"๐", ":oncoming_automobile:"=>"๐", ":car:"=>"๐", ":red_car:"=>"๐", ":taxi:"=>"๐", ":oncoming_taxi:"=>"๐", ":articulated_lorry:"=>"๐", ":bus:"=>"๐", ":oncoming_bus:"=>"๐", ":rotating_light:"=>"๐จ", ":police_car:"=>"๐", ":oncoming_police_car:"=>"๐", ":fire_engine:"=>"๐", ":ambulance:"=>"๐", ":minibus:"=>"๐", ":truck:"=>"๐", ":train:"=>"๐", ":station:"=>"๐", ":train2:"=>"๐", ":bullettrain_front:"=>"๐ ", ":bullettrain_side:"=>"๐", ":light_rail:"=>"๐", ":monorail:"=>"๐", ":railway_car:"=>"๐", ":trolleybus:"=>"๐", ":ticket:"=>"๐ซ", ":fuelpump:"=>"โฝ๏ธ", ":vertical_traffic_light:"=>"๐ฆ", ":traffic_light:"=>"๐ฅ", ":warning:"=>"โ ๏ธ", ":construction:"=>"๐ง", ":beginner:"=>"๐ฐ", ":atm:"=>"๐ง", ":slot_machine:"=>"๐ฐ", ":busstop:"=>"๐", ":barber:"=>"๐", ":hotsprings:"=>"โจ๏ธ", ":checkered_flag:"=>"๐", ":crossed_flags:"=>"๐", ":izakaya_lantern:"=>"๐ฎ", ":moyai:"=>"๐ฟ", ":circus_tent:"=>"๐ช", ":performing_arts:"=>"๐ญ", ":round_pushpin:"=>"๐", ":triangular_flag_on_post:"=>"๐ฉ", ":jp:"=>"๐ฏ๐ต", ":kr:"=>"๐บ๐ฆ", ":cn:"=>"๐จ๐ณ", ":us:"=>"๐บ๐ธ", ":fr:"=>"๐ซ๐ท", ":es:"=>"๐ช๐ธ", ":it:"=>"๐ฎ๐น", ":ru:"=>"๐ท๐บ", ":gb:"=>"๐ฌ๐ง", ":uk:"=>"๐ฌ๐ง", ":de:"=>"๐ฉ๐ช", ":one:"=>"1๏ธโฃ", ":two:"=>"2๏ธโฃ", ":three:"=>"3๏ธโฃ", ":four:"=>"4๏ธโฃ", ":five:"=>"5๏ธโฃ", ":six:"=>"6๏ธโฃ", ":seven:"=>"7๏ธโฃ", ":eight:"=>"8๏ธโฃ", ":nine:"=>"9๏ธโฃ", ":keycap_ten:"=>"๐", ":1234:"=>"๐ข", ":zero:"=>"0๏ธโฃ", ":hash:"=>"#๏ธโฃ", ":symbols:"=>"๐ฃ", ":arrow_backward:"=>"โ๏ธ", ":arrow_down:"=>"โฌ๏ธ", ":arrow_forward:"=>"โถ๏ธ", ":arrow_left:"=>"โฌ ๏ธ", ":capital_abcd:"=>"๐ ", ":abcd:"=>"๐ก", ":abc:"=>"๐ค", ":arrow_lower_left:"=>"โ๏ธ", ":arrow_lower_right:"=>"โ๏ธ", ":arrow_right:"=>"โก", ":arrow_up:"=>"โฌ๏ธ", ":arrow_upper_left:"=>"โ๏ธ", ":arrow_upper_right:"=>"โ", ":arrow_double_down:"=>"โฌ", ":arrow_double_up:"=>"โซ", ":arrow_down_small:"=>"๐ฝ", ":arrow_heading_down:"=>"โคต๏ธ๏ธ", ":arrow_heading_up:"=>"โคด๏ธ", ":leftwards_arrow_with_hook:"=>"โฉ", ":arrow_right_hook:"=>"โช๏ธ", ":left_right_arrow:"=>"โ", ":arrow_up_down:"=>"โ๏ธ", ":arrow_up_small:"=>"๐ผ", ":arrows_clockwise:"=>"๐", ":arrows_counterclockwise:"=>"๐", ":rewind:"=>"โช", ":fast_forward:"=>"โฉ", ":information_source:"=>"โน", ":ok:"=>"๐", ":twisted_rightwards_arrows:"=>"๐", ":repeat:"=>"๐", ":repeat_one:"=>"๐", ":new:"=>"๐", ":top:"=>"๐", ":up:"=>"๐", ":cool:"=>"๐", ":free:"=>"๐", ":ng:"=>"๐", ":cinema:"=>"๐ฆ", ":koko:"=>"๐", ":signal_strength:"=>"๐ถ", ":u5272:"=>"๐น", ":u5408:"=>"๐ด", ":u55b6:"=>"๐บ", ":u6307:"=>"๐ฏ๏ธ", ":u6708:"=>"๐ท๏ธ", ":u6709:"=>"๐ถ", ":u6e80:"=>"๐ต", ":u7121:"=>"๐๏ธ", ":u7533:"=>"๐ธ", ":u7a7a:"=>"๐ณ", ":u7981:"=>"๐ฒ", ":sa:"=>"๐๏ธ", ":restroom:"=>"๐ป", ":mens:"=>"๐น", ":womens:"=>"๐บ", ":baby_symbol:"=>"๐ผ", ":no_smoking:"=>"๐ญ", ":parking:"=>"๐ ฟ๏ธ", ":wheelchair:"=>"โฟ๏ธ", ":metro:"=>"๐", ":baggage_claim:"=>"๐", ":accept:"=>"๐", ":wc:"=>"๐พ", ":potable_water:"=>"๐ฐ", ":put_litter_in_its_place:"=>"๐ฎ", ":secret:"=>"ใ๏ธ", ":congratulations:"=>"ใ๏ธ", ":m:"=>"โ๏ธ", ":passport_control:"=>"๐", ":left_luggage:"=>"๐ ", ":customs:"=>"๐", ":ideograph_advantage:"=>"๐", ":cl:"=>"๐", ":sos:"=>"๐", ":id:"=>"๐", ":no_entry_sign:"=>"๐ซ", ":underage:"=>"๐", ":no_mobile_phones:"=>"๐ต", ":do_not_litter:"=>"๐ฏ", ":non-potable_water:"=>"๐ฑ", ":no_bicycles:"=>"๐ณ", ":no_pedestrians:"=>"๐ท", ":children_crossing:"=>"๐ธ", ":no_entry:"=>"โ", ":eight_spoked_asterisk:"=>"โณ", ":sparkle:"=>"โ", ":eight_pointed_black_star:"=>"โด", ":heart_decoration:"=>"๐", ":vs:"=>"๐", ":vibration_mode:"=>"๐ณ", ":mobile_phone_off:"=>"๐ด", ":chart:"=>"๐น", ":currency_exchange:"=>"๐ฑ", ":aries:"=>"โ", ":taurus:"=>"โ", ":gemini:"=>"โ", ":cancer:"=>"โ", ":leo:"=>"โ", ":virgo:"=>"โ", ":libra:"=>"โ", ":scorpius:"=>"โ", ":sagittarius:"=>"โ", ":capricorn:"=>"โ", ":aquarius:"=>"โ", ":pisces:"=>"โ", ":ophiuchus:"=>"โ", ":six_pointed_star:"=>"๐ฏ", ":negative_squared_cross_mark:"=>"โ", ":a:"=>"๐ ฐ๏ธ", ":b:"=>"๐ ฑ๏ธ", ":ab:"=>"๐", ":o2:"=>"๐ พ๏ธ", ":diamond_shape_with_a_dot_inside:"=>"๐ ", ":recycle:"=>"โป๏ธ", ":end:"=>"๐", ":back:"=>"๐", ":on:"=>"๐", ":soon:"=>"๐", ":clock1:"=>"๐", ":clock130:"=>"๐", ":clock10:"=>"๐", ":clock1030:"=>"๐ฅ", ":clock11:"=>"๐", ":clock1130:"=>"๐ฆ", ":clock12:"=>"๐", ":clock1230:"=>"๐", ":clock2:"=>"๐", ":clock230:"=>"๐", ":clock3:"=>"๐", ":clock330:"=>"๐", ":clock4:"=>"๐", ":clock430:"=>"๐", ":clock5:"=>"๐", ":clock530:"=>"๐ ", ":clock6:"=>"๐", ":clock630:"=>"๐ก", ":clock7:"=>"๐", ":clock730:"=>"๐ข", ":clock8:"=>"๐", ":clock830:"=>"๐ฃ", ":clock9:"=>"๐", ":clock930:"=>"๐ค", ":heavy_dollar_sign:"=>"๐ฒ", ":copyright:"=>"ยฉ๏ธ", ":registered:"=>"ยฎ๏ธ", ":tm:"=>"โข๏ธ", ":x:"=>"โ", ":heavy_exclamation_mark:"=>"โ๏ธ", ":bangbang:"=>"โผ๏ธ", ":interrobang:"=>"โ๏ธ", ":o:"=>"โญ๏ธ", ":heavy_multiplication_x:"=>"โ", ":heavy_plus_sign:"=>"โ", ":heavy_minus_sign:"=>"โ", ":heavy_division_sign:"=>"โ", ":white_flower:"=>"๐ฎ", ":100:"=>"๐ฏ", ":heavy_check_mark:"=>"โ", ":ballot_box_with_check:"=>"โ", ":radio_button:"=>"๐", ":link:"=>"๐", ":curly_loop:"=>"โฐ", ":wavy_dash:"=>"ใฐ", ":part_alternation_mark:"=>"ใฝ", ":trident:"=>"๐ฑ", ":black_small_square:"=>"โช", ":white_small_square:"=>"โซ", ":black_medium_small_square:"=>"โพ", ":white_medium_small_square:"=>"โฝ", ":black_medium_square:"=>"โผ", ":white_medium_square:"=>"โป", ":black_large_square:"=>"โฌ", ":white_large_square:"=>"โฌ", ":white_check_mark:"=>"โ ", ":black_square_button:"=>"๐ฒ", ":white_square_button:"=>"๐ณ", ":black_circle:"=>"โซ๏ธ", ":white_circle:"=>"โช๏ธ", ":red_circle:"=>"๐ด", ":large_blue_circle:"=>"๐ต", ":large_blue_diamond:"=>"๐ท", ":large_orange_diamond:"=>"๐ถ", ":small_blue_diamond:"=>"๐น", ":small_orange_diamond:"=>"๐ธ", ":small_red_triangle:"=>"๐บ", ":small_red_triangle_down:"=>"๐ป" }
- VERSION =
"1.0.0"
Class Method Summary collapse
-
.parse(string) ⇒ Object
Parse a string to convert the colon notation into a real emoji.
Class Method Details
.parse(string) ⇒ Object
Parse a string to convert the colon notation into a real emoji.
Example:
>> RubyEmoji.parse(":grin: :green_heart:")
=> "๐ ๐"
12 13 14 15 |
# File 'lib/ruby_emoji.rb', line 12 def self.parse(string) parser = Parser.new(string) parser.parse end |